import _ from 'lodash';
import React, { useCallback, useState } from 'react';
import CustomFormField from '../form/CustomFormField';
import useUpdateEffect from '../hooks/useUpdateEffect';
import Pagination from './Pagination';
import TableSearch from './TableSearch';
const TablePaginatedSearch = ({
  paginatedItems,
  setPaginatedItems = () => {},
  fields = [],
  editItem = null,
  deleteItem = null,
  actions = [],
  hideSearch = false
}) => {
  const [search, setSearch] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  useUpdateEffect(() => {
    searchItems(search);
  }, [search]);
  const fetchItems = useCallback((search, page = 1) => {
    setIsLoading(true);
    Promise.resolve(setPaginatedItems(search, page)).then(() => setIsLoading(false));
  }, []);
  const searchItems = useCallback(_.debounce(search => fetchItems(search), 500), []);
  return /*#__PURE__*/React.createElement(React.Fragment, null, paginatedItems != null && /*#__PURE__*/React.createElement("div", {
    className: "table-paginated-search"
  }, !hideSearch && /*#__PURE__*/React.createElement(CustomFormField, {
    label: "Rechercher",
    value: search,
    onChange: value => setSearch(value)
  }), !isLoading ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TableSearch, {
    items: paginatedItems.items,
    fields: fields,
    editItem: editItem,
    deleteItem: deleteItem,
    hideSearch: true,
    actions: actions
  }), /*#__PURE__*/React.createElement(Pagination, {
    pagination: paginatedItems,
    fetch: page => fetchItems(search, page)
  })) : /*#__PURE__*/React.createElement("div", {
    className: "flex center"
  }, /*#__PURE__*/React.createElement("div", {
    className: "spinner-border text-primary",
    role: "status"
  }))));
};
export default TablePaginatedSearch;