import React, { useEffect, useMemo, useState } from 'react';
import { Document, Page, pdfjs } from 'react-pdf';
pdfjs.GlobalWorkerOptions.workerSrc = new URL('pdfjs-dist/build/pdf.worker.min.js', import.meta.url).toString();
const PDFView = ({
  file,
  width,
  displayLastPage = false
}) => {
  const [numPages, setNumPages] = useState(null);
  const [pageNumber, setPageNumber] = useState(1);
  const [fileURL, setFileURL] = useState(null);
  useEffect(() => {
    if (file != null && file.type === 'application/pdf') {
      const objectURL = URL.createObjectURL(file);
      setFileURL(objectURL);
    } else if (typeof file === 'string') {
      setFileURL(file);
    }
  }, [file]);
  useEffect(() => {
    if (numPages != null) {
      setPageNumber(displayLastPage ? numPages : 1);
    }
  }, [numPages, displayLastPage]);
  function onDocumentLoadSuccess({
    numPages
  }) {
    setNumPages(numPages);
  }
  const isFirstPage = useMemo(() => pageNumber === 1, [pageNumber]);
  const isLastPage = useMemo(() => pageNumber === numPages, [pageNumber, numPages]);
  return /*#__PURE__*/React.createElement("div", {
    className: "pdf-view"
  }, fileURL != null && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: "pdf-buttons spaced-inline"
  }, /*#__PURE__*/React.createElement("button", {
    className: "btn btn-outline-primary",
    onClick: () => setPageNumber(pageNumber - 1),
    disabled: isFirstPage,
    type: "button"
  }, "Page pr\xE9c\xE9dente"), /*#__PURE__*/React.createElement("button", {
    className: "btn btn-outline-primary",
    onClick: () => setPageNumber(pageNumber + 1),
    disabled: isLastPage,
    type: "button"
  }, "Page suivante")), /*#__PURE__*/React.createElement(Document, {
    loading: /*#__PURE__*/React.createElement("p", {
      className: "informations "
    }, /*#__PURE__*/React.createElement("span", {
      className: "spinner-border"
    }, /*#__PURE__*/React.createElement("span", {
      className: "sr-only"
    }))),
    file: fileURL,
    onLoadSuccess: onDocumentLoadSuccess
  }, !isFirstPage && /*#__PURE__*/React.createElement(Page, {
    className: "prev-page",
    pageNumber: pageNumber - 1,
    renderTextLayer: false,
    renderAnnotationLayer: false,
    width: width
  }), /*#__PURE__*/React.createElement(Page, {
    pageNumber: pageNumber,
    renderTextLayer: false,
    renderAnnotationLayer: false,
    width: width
  }), !isLastPage && /*#__PURE__*/React.createElement(Page, {
    className: "next-page",
    pageNumber: pageNumber + 1,
    renderTextLayer: false,
    renderAnnotationLayer: false,
    width: width
  }))));
};
export default PDFView;