import axios from 'axios';

// import TokenManager from "./TokenManager"

// const completeServerURL = `${process.env.API_URL}/api`

const queryStringBuild = (url, isAPIRequest = true) => {
  var resURL = url;
  if (!url.includes('http://') && !url.includes('https://')) {
    resURL = `${isAPIRequest ? '/api' : ''}${url}`;
  }
  return resURL;
};
const setHeaders = () => {
  const headers = {};
  if (window.USER_API_KEY != null) headers['X-AUTH-TOKEN'] = window.USER_API_KEY;
  return headers;
};

// const checkHttpError = res => {
//     if (!res.ok) {
//         if (res.status === 401 && res.statusText === 'Unauthorized') {
//             TokenManager.removeToken()
//         }
//         throw `${res.status} ${res.statusText}`
//     }
//     return res
// }

const checkError = res => {
  if (res != null) {
    if (res['@type'] === 'hydra:Error') {
      throw res['hydra:description'];
    }
  }
  return res;
};
class Http {
  static get = (url, params = null, options = {}, isAPIRequest = true) => {
    return axios.get(queryStringBuild(url, isAPIRequest), {
      params,
      headers: setHeaders(),
      ...options
    }).then(response => response.data);
  };
  static post = (url, body, params = null, isAPIRequest = true) => {
    return axios.post(queryStringBuild(url, isAPIRequest), JSON.stringify(body), {
      params,
      headers: setHeaders()
    }).then(response => response.data);
  };
  static delete = (url, params = null, isAPIRequest = true) => {
    return axios.delete(queryStringBuild(url, isAPIRequest), {
      headers: setHeaders(),
      params
    }).then(response => response.data);
  };
  static put = (url, body, params = null, isAPIRequest = true) => {
    return axios.put(queryStringBuild(url, isAPIRequest), JSON.stringify(body), {
      params,
      headers: {
        'Content-Type': 'application/merge-patch+json',
        ...setHeaders()
      }
    }).then(response => response.data);
  };
  static patch = (url, body, params = null, isAPIRequest = true) => {
    return axios.patch(queryStringBuild(url, isAPIRequest), JSON.stringify(body), {
      params,
      headers: {
        'Content-Type': 'application/merge-patch+json',
        ...setHeaders()
      }
    }).then(response => response.data);
  };
  static postFormData = (url, formData, params = null, isAPIRequest = true) => {
    return axios.post(queryStringBuild(url, isAPIRequest), formData, {
      params,
      headers: setHeaders()
    }).then(response => response.data);
  };
}
export default Http;